@@ -1,14 +1,24 @@
 
 #==============================================================================#
-# $Id: config.rb,v 1.9 2003/10/30 17:00:47 yuya Exp $
+# $Id: config.rb,v 1.15 2005/04/14 16:54:45 yuya Exp $
+#==============================================================================#
+
+require 'rbconfig'
+
 #==============================================================================#
 
 module Exerb
 
-  CORE_PATH   = ['.']
-  CORE_NAME   = {'cui' => 'ruby180c.exc', 'cuirt' => 'ruby180crt.exc', 'gui' => 'ruby180g.exc', 'guirt' => 'ruby180grt.exc'}
-  PLUGIN_PATH = ['.']
-  PLUGIN_NAME = {'zlib' => 'mod_zlib.exm', 'bruby' => 'mod_bruby.exm'}
+  CORE_PATH   = [File.join(Config::CONFIG['datadir'], 'exerb'), '.']
+  CORE_NAME   = {'cui' => 'ruby182c.exc', 'cuirt' => 'ruby182crt.exc', 'gui' => 'ruby182g.exc', 'guirt' => 'ruby182grt.exc'}
+  PLUGIN_PATH = [File.join(Config::CONFIG['datadir'], 'exerb'), '.']
+  PLUGIN_NAME = {}
+
+  if $Exerb
+    selfpath = File.dirname(Exerb.filepath)
+    CORE_PATH   << selfpath
+    PLUGIN_PATH << selfpath
+  end
 
 end # Exerb
 
