@@ -1,5 +1,7 @@
-// $Id: resource.h,v 1.14 2003/10/30 16:46:52 yuya Exp $
+// $Id: resource.h,v 1.33 2005/03/14 11:57:17 yuya Exp $
 
+#define RT_EXERB                        100
+#define ID_EXERB                        100
 #define IDD_EXCEPTION                   101
 #define IDI_RUBY                        102
 
@@ -12,6 +14,5 @@
 #define IDC_STATIC -1
 #endif
 
-#define EXERB_RES_EXERB_VERSION1 3,0,0,0
-#define EXERB_RES_EXERB_VERSION2 "3.0.0-preview1"
-#define EXERB_RES_RUBY_VERSION "1.8.0"
+#define EXERB_RES_EXERB_VERSION1 3,3,0,0
+#define EXERB_RES_EXERB_VERSION2 "3.3.0"
